@@ -51,6 +51,10 @@ def clean_form(base: Any, cols: list, form: dict):
     return inputs
 
 
+def clean_update_form(base: Any, cols: list, form: dict):
+    clean = clean_form(base, cols, form)
+    return {key: val for key, val in clean.items() if val and val in form.keys()}
+
 # Testing
 class SQLBase:
     """SQlAlchemy & Databases (Manager)
@@ -64,6 +68,7 @@ class SQLBase:
     # Form
     -----------------------------------------------------------------------------------------------
     - Clean-Inputs      : sql.form(dict)
+    - Clean-Empty       : sql.form_update(dict)
 
     -----------------------------------------------------------------------------------------------
     # Read (Examples)
@@ -90,6 +95,7 @@ class SQLBase:
         self.table = custom_type.objects
         self.Q = SQLFilters(custom_type.objects)
         self.form = functools.partial(clean_form, custom_type, custom_type.objects.columns.keys())
+        self.form_update = functools.partial(clean_update_form, custom_type, custom_type.objects.columns.keys())
 
     async def find(
         self,
